﻿#!/bin/bash

# Graphen zeichnen mit <I>gnuplot<I>

# Struktur der Input-Datei
# 1 Zeile pro Sensor und Wert
# 03.11.2014 16:25:03 Sensor 0 C: 19.69  # Innentemperatur
# 03.11.2014 16:25:05 Sensor 1 C: 9.38   # Aussentemperatur
# 03.11.2014 16:25:02 Sensor 2 C: 48.88  # Vorlauftemperatur
# 03.11.2014 16:25:06 Sensor 3 C: 37.25  # Ruecklauftemperatur
# 03.11.2014 16:25:06 Sensor 4 C: 1.25   # Gasmenge in m3
# ...

# Variablen setzen
bin="/energymon"
datas="$bin/data"
i_file="$datas/temperature.log"
tmp="/tmp"
o_file="sensor.jpeg"

# Dateityp und Groesse der Ausgabedatei festlegen
bildformat="jpeg small size 1024,768 "

# Graphenueberschrift festlegen
titel=" \nSensordaten vom `date +'%d.%m.%Y %H:%M:%S'` " 

# Anzeigebereich festlegen:
# 3 Tage = 72 Stunden = 864 unit à 5 Minuten
units="864"

# Linienstaerke festlegen
breite=" linewidth 1 "

# gnuplot-Farbliste: 
## -1=black 1=red 2=grn 3=blue 4=purple 5=aqua 6=brn 7=orange 8=light-brn

# Werte der einzelnen Sensoren in eine temporaere Datei extrahieren
grep "Sensor 0" $i_file |tail -$units >$tmp/0.tmp
grep "Sensor 1" $i_file |tail -$units >$tmp/1.tmp
grep "Sensor 2" $i_file |tail -$units >$tmp/2.tmp
grep "Sensor 3" $i_file |tail -$units >$tmp/3.tmp
grep "Sensor 4" $i_file |tail -$units >$tmp/3.tmp

# Generieren der Plotbeschreibung
## "Wertedatei" using "Feld 6" "Linienstaerke" "Linienfarbe" with "durchgezogene Linie" title " Beschriftung in der Legende",

plot_arg="\"$tmp/0.tmp\" using 1:6 $breite lc 1 with lines title \"Innentemperatur\",\
\"$tmp/1.tmp\" using 1:6 $breite lc 3 with lines title \"Aussentemperatur\",\
\"$tmp/2.tmp\" using 1:6 $breite lc 2 with lines title  \"Vorlauftemperatur\",\
\"$tmp/3.tmp\" using 1:6 $breite lc 7 with lines title \"Ruecklauftemperatur\",\
\"$tmp/4.tmp\" using 1:6 $breite lc -1 with lines title \"GAS gesamt\"   \
smooth unique"

# Beschreibung an gnuplot uebergeben und Graphen in Datei schreiben
gnuplot -persist << END_DATA   #2>/dev/null
set timefmt "%d.%m.%Y %H:%M"   # Zeitformat
set xdata time                 # x-Achsen mit Datum und Zeit
set format x "%H:%M\n%d.%m"    # Zeit und Datum mit Zeilenumbruch versehen
set key left                   # Legende links
set terminal $bildformat       # Grafikformat zuweisen
set output "$datas/$o_file"    # Ausgabe festlegen
set ytics 2.5                  # Legende y-Achse links
set y2tics 2.5                 # Legende y-Achse rechts
set grid xtics ytics           # Hintergrundraster anzeigen
set title "$titel"             # Ueberschrift setzen
set bmargin 3
set tmargin 3                  # Raender des Graphen
plot $plot_arg
END_DATA

# erstellte Graphik zum HTTP-Server kopieren
scp $datas/$o_file httpserver://home/www/$o_file >/dev/null

